@@ -14,6 +14,7 @@ import requests
 import logging
 import six
 import sentry
+import sentry_dingtalk_bot
 
 from django import forms
 from django.conf import settings
@@ -27,49 +28,40 @@ from sentry.utils.safe import safe_execute
 from sentry.utils.http import absolute_uri
 from django.core.urlresolvers import reverse
 
-import sentry_dingtalk_bot
-
-
-
-# def validate_urls(value, **kwargs):
-#     output = []
-#     for url in value.split('\n'):
-#         url = url.strip()
-#         if not url:
-#             continue
-#         if not url.startswith(('http://', 'https://')):
-#             raise PluginError('Not a valid URL.')
-#         if not is_valid_url(url):
-#             raise PluginError('Not a valid URL.')
-#         output.append(url)
-#     return '\n'.join(output)
+def validate_urls(value, **kwargs):
+    output = []
+    for url in value.split('\n'):
+        url = url.strip()
+        if not url:
+            continue
+        if not url.startswith(('http://', 'https://')):
+            raise PluginError('Not a valid URL.')
+        if not is_valid_url(url):
+            raise PluginError('Not a valid URL.')
+        output.append(url)
+    return '\n'.join(output)
 
 
 class DingtalkForm(notify.NotificationConfigurationForm):
-    webhook_url = forms.CharField(
+    urls = forms.CharField(
         label=_('Dingtalk robot url'),
         widget=forms.Textarea(attrs={
             'class': 'span6', 'placeholder': 'https://oapi.dingtalk.com/robot/send?access_token=9bacf9b193f'}),
         help_text=_('Enter dingtalk robot url.'))
 
-    custom_keyword = forms.CharField(
-        label=_('Custom Keyword'),
-        widget=forms.CharField(attrs={'placeholder': 'keywords'}),
-        help_text=_('Enter custom keyword.'))
-
-    # def clean_url(self):
-    #     value = self.cleaned_data.get('url')
-    #     return validate_urls(value)
+    def clean_url(self):
+        value = self.cleaned_data.get('url')
+        return validate_urls(value)
 
  
 class DingtalkPlugin(notify.NotificationPlugin):
     author = 'lpcoder'
-    author_url = 'https://github.com/liupcoder/sentry_dingtalk_bot'
+    author_url = ''
     version = sentry_dingtalk_bot.VERSION
     description = "Integrates dingtalk robot."
     resource_links = [
-        ('Bug Tracker', 'https://github.com/liupcoder/sentry_dingtalk_bot/issues'),
-        ('Source', 'https://github.com/liupcoder/sentry_dingtalk_bot'),
+        ('Bug Tracker', ''),
+        ('Source', ''),
     ]
 
     slug = 'dingtalk'
@@ -82,41 +74,32 @@ class DingtalkPlugin(notify.NotificationPlugin):
     logger = logging.getLogger('sentry.plugins.dingtalk')
 
     def is_configured(self, project, **kwargs):
-        return bool(self.get_option('webhook_url', project))
+        return bool(self.get_option('urls', project))
 
     def get_config(self, project, **kwargs):
         return [{
-            'name': 'webhook_url',
+            'name': 'urls',
             'label': 'dingtalk robot url',
             'type': 'textarea',
             'help': 'Enter dingtalk robot url.',
             'placeholder': 'https://oapi.dingtalk.com/robot/send?access_token=abcdefg',
             'validators': [validate_urls],
-            'required': True
-        },
-        {
-            'name': 'custom_keyword',
-            'label': 'Custom Keyword',
-            'type': 'input',
-            'help': 'Enter custom keyword.',
-            'placeholder': 'Error',
             'required': False
-        }
-        ] 
+        }] 
 
     def get_webhook_urls(self, project):
-        url = self.get_option('webhookUrl', project)
+        url = self.get_option('urls', project)
         if not url:
             return ''
         return url 
 
-    # def send_webhook(self, url, payload):
-    #     return safe_urlopen(
-    #         url=url,
-    #         json=payload,
-    #         timeout=self.timeout,
-    #         verify_ssl=False,
-    #     )
+    def send_webhook(self, url, payload):
+        return safe_urlopen(
+            url=url,
+            json=payload,
+            timeout=self.timeout,
+            verify_ssl=False,
+        )
 
     def get_group_url(self, group):
         '''
@@ -135,7 +118,7 @@ class DingtalkPlugin(notify.NotificationPlugin):
             return
         url = self.get_webhook_urls(group.project)
         link = self.get_group_url(group)
-        message_format = '[%s] %s   %s'
+        message_format = '[Error]\n[%s]\n%s\n%s'
         message = message_format % (event.title, event.message, link)
         data = {"msgtype": "text",
                     "text": {
